@@ -9,7 +9,7 @@ from .context import Context
 from .loader import FilesystemLoader
 from .parser import Parser, Context as ParserContext, Argument
 from .executor import Executor
-from .exceptions import Failure, CollectionNotFound, ParseError
+from .exceptions import Failure, CollectionNotFound, ParseError, Exit
 from .util import debug, pty_size, enable_logging
 from ._version import __version__
 
@@ -85,10 +85,9 @@ def parse(argv, collection=None, version=None):
     """
     # Initial/core parsing (core options can affect the rest of the parsing)
     initial_context = ParserContext(args=(
-        # TODO: make '--collection' a list-building arg, not a string
         Argument(
             names=('collection', 'c'),
-            help="Specify collection name to load. May be given >1 time."
+            help="Specify collection name to load."
         ),
         Argument(
             names=('root', 'r'),
@@ -163,7 +162,7 @@ def parse(argv, collection=None, version=None):
             print(version)
         else:
             print("Invoke %s" % __version__)
-        sys.exit(0)
+        raise Exit
 
     # Core (no value given) --help output
     # TODO: if this wants to display context sensitive help (e.g. a combo help
@@ -177,17 +176,24 @@ def parse(argv, collection=None, version=None):
         print("")
         print("Core options:")
         print_help(initial_context.help_tuples())
-        sys.exit(0)
+        raise Exit
 
     # Load collection (default or specified) and parse leftovers
-    # (Skip loading if somebody gave us an explicit task collection.)
-    if not collection:
-        debug("No collection given, loading from %r" % args.root.value)
-        loader = FilesystemLoader(start=args.root.value)
-        start = args.collection.value
-        collection = loader.load(start) if start else loader.load()
+    start = args.root.value
+    loader = FilesystemLoader(start=start)
+    coll_name = args.collection.value
+    try:
+        collection = loader.load(coll_name) if coll_name else loader.load()
+    except CollectionNotFound:
+        # TODO: improve sys.exit mocking in tests so we can just raise
+        # Exit(msg)
+        six.print_(
+            "Can't find any collection named {0!r}!".format(coll_name),
+            file=sys.stderr
+        )
+        raise Exit(1)
     parser = Parser(contexts=collection.to_contexts())
-    debug("Parsing actual tasks against collection %r" % collection)
+    debug("Parsing tasks against collection %r" % collection)
     tasks = parse_gracefully(parser, core.unparsed)
 
     # Per-task help. Use the parser's contexts dict as that's the easiest way
@@ -220,13 +226,17 @@ def parse(argv, collection=None, version=None):
         else:
             print(indent + "none")
             print("")
-        sys.exit(0)
+        raise Exit
 
     # Print discovered tasks if necessary
     if args.list.value:
-        print("Available tasks:\n")
         # Sort in depth, then alpha, order
         task_names = collection.task_names
+        # Short circuit if no tasks to show
+        if not task_names:
+            msg = "No tasks found in collection '{0}'!"
+            print(msg.format(collection.name))
+            raise Exit
         pairs = []
         for primary in sort_names(task_names.keys()):
             # Add aliases
@@ -242,8 +252,9 @@ def parse(argv, collection=None, version=None):
             pairs.append((name, help_))
 
         # Print
+        print("Available tasks:\n")
         print_help(pairs)
-        sys.exit(0)
+        raise Exit
 
     # Return to caller so they can handle the results
     return args, collection, tasks
@@ -262,7 +273,12 @@ def derive_opts(args):
     return {'run': run}
 
 def dispatch(argv, version=None):
-    args, collection, parser_contexts = parse(argv, version=version)
+    try:
+        args, collection, parser_contexts = parse(argv, version=version)
+    except Exit as e:
+        # 'return' here is mostly a concession to testing. Meh :(
+        # TODO: probably restructure things better so we don't need this?
+        return sys.exit(e.code)
     executor = Executor(collection, Context(**derive_opts(args)))
     try:
         tasks = []
