@@ -33,3 +33,13 @@ class ParseError(Exception):
     def __init__(self, msg, context=None):
         super(ParseError, self).__init__(msg)
         self.context = context
+
+
+class Exit(Exception):
+    """
+    Simple stand-in for SystemExit that lets us gracefully exit.
+
+    Removes lots of scattered sys.exit calls, improves testability.
+    """
+    def __init__(self, code=0):
+        self.code = code
