@@ -41,6 +41,12 @@ class CLI(IntegrationSpec):
                 "whatevs\n",
             )
 
+    def missing_collection_yields_useful_error(self):
+        _output_eq(
+            '-c huhwhat -l',
+            stderr="Can't find any collection named 'huhwhat'!\n"
+        )
+
     def contextualized_tasks_are_given_parser_context_arg(self):
         # go() in contextualized.py just returns its initial arg
         retval = list(_dispatch('invoke -c contextualized go').values())[0]
@@ -60,8 +66,7 @@ Usage: inv[oke] [--core-opts] task1 [--task1-opts] ... taskN [--taskN-opts]
 
 Core options:
   --no-dedupe                      Disable task deduplication.
-  -c STRING, --collection=STRING   Specify collection name to load. May be
-                                   given >1 time.
+  -c STRING, --collection=STRING   Specify collection name to load.
   -d, --debug                      Enable debug output.
   -e, --echo                       Echo executed commands before running.
   -h [STRING], --help[=STRING]     Show core or per-task help and exit.
@@ -214,6 +219,12 @@ Available tasks:
                 'with_aliases (a, b)   foo',
             ))
 
+        def empty_collections_say_no_tasks(self):
+            _output_eq(
+                "-c empty -l",
+                "No tasks found in collection 'empty'!\n"
+            )
+
     def debug_flag_activates_logging(self):
         # Have to patch our logger to get in before Nose logcapture kicks in.
         with patch('invoke.util.debug') as debug:
@@ -396,11 +407,3 @@ class CLIParsing(Spec):
             a = r[0].args
             eq_(a.b.value, True)
             eq_(a.v.value, True)
-
-    def globbed_shortflags_with_multipass_parsing(self):
-        "mytask -cb and -bc"
-        for args in ('-bc', '-cb'):
-            _, _, r = parse(['invoke', 'mytask4', args], self.c)
-            a = r[0].args
-            eq_(a.clean.value, True)
-            eq_(a.browse.value, True)
